; Copyright David Moriano Garca (2001), lvaro Tejero Cantero
; (alvaro@antalia.com, 2001,2002,2003).
("a modifier" "modificador A")
("GNU" "GNU")
("h modifier" "modificador H")
("LaTeX" "LaTeX")
("m modifier" "modificador M")
("TeX" "TeX")
("abbreviation" "abreviatura")
("about" "acerca de")
("about menu" "men acerca de")
("above" "encima")
("abstract" "resumen")
("accent" "acento")
("accept" "aceptar")
;?
("accept all scripts" "aceptar todos los guiones")
("accept no scripts" "no aceptar guiones")
("accept script" "aceptar guin")
("acknowledgment" "reconocimiento")
("acronym" "acrnimo")
("action" "accin")
("activate" "activar")
("acute" "agudo")
("add switch after" "aadir fotograma antes")
("add switch before" "aadir fotograma despus")
("address" "direccin")
("address block" "direccin")
("advanced" "avanzado")
("advanced layout features" "funciones de composicin avanzadas")
("after" "despus de")
("albanian" "albans")
("algorithm" "algoritmo")
("align cell to the bottom" "alinear celda por abajo")
("align cell to the left" "alinear celda a la izquierda")
("align cell to the right" "alinear celda a la derecha")
("align cell to the top" "alinear celda arriba")
("align table at base of left column" "alinear tabla con la base de la columna izquierda")
("align table at base of middle column" "alinear tabla con la base de la columna central")
("align table at base of origin column" "alinear tabla a la base de la columna original")
("align table at base of right column" "alinear tabla con la base de la columna derecha")
("align table at fraction bar height" "alinear tabla a la altura de la barra defraccin")
("align table at the base of bottom row" "alinear tabla a la base de la fila inferior")
("align table at the base of middle row" "alinear tabla a la base de la fila central")
("align table at the base of origin row" "alinear tabla a la base de la fila original")
("align table at the base of top row" "alinear tabla a la base de la fila superior")
("align table at the bottom" "alinear tabla por abajo")
("align table at the center" "alinear tabla por el centro")
("align table at the horizontal center" "alinear tabla por el centro horizontal")
("align table at the left" "alinear tabla a la izquierda")
("align table at the top" "alinear tabla arriba")
("align table to the right" "alinear tabla a la derecha")
("align text to the left" "alinear el texto a la izquierda")
("align text to the right" "alinear el texto a la derecha")
("aligned" "alineada")
("alignment" "alineacin")
("all" "todo")
("allow" "permitir")
("allowed extension" "extensin permitida")
("allowed reduction" "reduccin permitida")
("alpha release" "versin alfa")
("alt key" "tecla alt")
("and" "y")
("appendix" "apndice")
("apply" "aplicar")
("april" "abril")
("arab" "rabe")
("archaic" "arcaica")
("architecture" "arquitectura")
("argument" "argumento")
("arithmetic" "aritmtica")
("armenian" "armenio")
("arrow" "flecha")
("arrows" "flechas")
("article" "artculo")
("as on paper" "como en papel")
("assign" "asignar")
("at fraction bar height" "a la altura de la raya de fraccin")
("at the baseline" "a la lnea base")
("at the bottom" "abajo")
("at the left" "a la izquierda")
("at the middle" "al medio")
("at the right" "a la derecha")
("at the top" "arriba")
("attach" "vincular")
("attach buffer to which project" "a qu proyecto vincular el bfer")
("august" "agosto")
("author" "autor")
("authorize" "autorizar")
("automatic" "automtico")
("automatically close brackets" "cerrar parntesis automticamente")
("automatically generated content" "contenido generado automticamente")
("axiom" "axioma")
("background" "fondo")
("background color" "color de fondo")
("backward replace" "sustituir hacia atrs")
("backward search" "buscar hacia atrs")
("bad data format" "formato de datos errneo")
("bar" "barra")
("bard" "bardo")
("base level" "nivel base")
("bashkirian" "bashkirian")
("basic" "bsico")
("basic data types" "tipos de datos bsicos")
("basic types" "tipos bsicos")
("be useful" "ser til")
("become a TeXmacs developer" "hazte desarrollador de TeXmacs")
("before" "antes de")
("begin" "principio")
("below" "debajo")
("beta release" "versin beta")
("bibliography" "bibliografa")
("bibliography file" "fichero de bibliografa")
("bibliography style" "estilo de bibliografa")
("big" "grande")
("big figure" "figura grande")
("big operator" "operador grande")
("big skip" "salto grande")
("big table" "tabla grande")
("binary operation" "operacin binaria")
("binary relation" "relacin binaria")
("black" "negro")
("blackboard bold" "negrita de pizarra")
("blackboard math" "matemtica de pizarra")
;?
("blackletter" "blackletter")
("blue" "azul")
("body" "cuerpo")
("bold" "negrita")
("book" "libro")
("border" "borde")
("both" "ambas")
("bottom" "al final")
("bottom border" "borde inferior")
("bottom margin" "margen inferior")
("bottom padding" "acolchado inferior")
("branch" "rama")
("break" "salto")
("breaking" "saltos")
;?
("breve" "breve")
("british" "britnico")
("broken white" "blanco roto")
("brown" "marrn")
("browse" "examinar")
("browse web" "examinar en la red")
("browser" "navegador")
("buffer" "bfer")
("bulgarian" "blgaro")
("bullet" "bolo")
("bullets" "bolos")
("by" "por")
("by typing" "escribiendo")
("bytes free" "bytes libres")
("bytes used" "bytes usados")
("calligraphic" "caligrfica")
("cancel" "cancelar")
("case" "caso")
("cc" "cc")
("cell" "celda")
("cell background color" "color de fondo de la celda")
("cell border" "borde de la celda")
("cell height" "altura de la celda")
("cell operation mode" "modo de operacin de la celda")
("cell width" "anchura de la celda")
("center" "centro")
("center text" "centrar texto")
("centered" "centrado")
("centered block" "bloque centrado")
("centered tabular" "tabla centrada")
("change border of cell" "cambiar borde de la celda")
("change cell operation mode" "cambiar modo de operacin de la celda")
("change log" "bitcora de cambios")
("changes" "cambios")
("chapter" "captulo")
;?
("check" "check")
("check text for spelling errors" "comprobar ortografa")
("chinese" "chino")
("choice" "eleccin")
("citation" "cita")
("cite" "cita")
("class" "clase")
("clear" "limpiar")
("clear selection" "borrar seleccin")
("clipped" "recortado")
("clipped and magnified" "recortado y ampliado")
("clipped and resized" "recortad y redimensionado")
("clone" "duplicar")
("clone window" "duplicar ventana")
("close" "cerrar")
("close TeXmacs" "cerrar TeXmacs")
("close buffer" "cerrar bfer")
("close session" "cerrar sesin")
("close window" "cerrar ventana")
("closing" "cierre")
("code" "cdigo")
("color" "color")
("column" "columna")
("column contains glued items" "la columna contiene elementos pegados")
("compact" "compacta")
("compatibility with other formats" "compatibilidad con otros formatos")
("compile article" "compilar artculo")
("compile book" "compilar libro")
("compile buffer" "compilar bfer")
("compile project" "compilar proyecto")
("complex" "compleja")
;?
("concrete" "concrete")
("condensed" "condensada")
("condition" "condicin")
("configuration" "configuracin")
("content tag" "marcar contenido")
("context dependent icons" "iconos dependientes del contexto")
("continuation of" "continuacin de")
("convention" "convenio")
("converters to other data formats" "convertidores a otros formatos de datos")
("copy" "copiar")
("copy text" "copiar texto")
("copy to" "copiar a")
("copying" "copiando")
("corollary" "corolario")
("correct text" "corregir texto")
("cursors" "cursores")
("custom tab" "tabulador personalizado")
;?

("customizing TeXmacs" "personalizacin de TeXmacs")
("customizing the TeXmacs styles" "personalizacin de los estilos de TeXmacs")
("cut" "cortar")
("cut text" "cortar texto")
("cut to" "cortar a")
("cypriot" "chipriota")
("cyrillic" "cirlico")
("cyrillic input method" "entrada de cirlico")
("cyrillic italic right" "cirlico cursiva recta")
("czech" "checo")
("dancers" "bailarines")
("danish" "dans")
("dark grey" "gris oscuro")
("dash" "guin")
("dashes" "guiones")
("data conversion" "conversin de datos")
("data format" "formato de datos")
("date" "fecha")
("deactivate" "desactivar")
("deactivate table" "desactivar tabla")
("december" "diciembre")
("decorate atoms" "decoraciones atmicas")
("default" "por defecto")
("default padding" "acolchado por defecto")
("definition" "definicin")
("delete" "borrar")
("delete column" "borrar columna")
("delete row" "borrar fila")
("denominator" "denominador")
("description" "descripcin")
("destination" "destino")
("detach" "desvincular")
("determinant" "determinante")
("devangari" "devangari")
("developers guide" "gua de programadores")
("directory" "directorio")
("disable first indentation" "deshabilitar primer sangrado")
("disable first indentation after" "deshabilitar primer sangrado posterior")
("disable first indentation before" "deshabilitar primer sangrado anterior")
("disable indentation" "deshabilitar sangrado")
("disable indentation after" "deshabilitar sangrado despus")
("disable indentation before" "deshabilitar sangrado antes")
("disable last indentation" "deshabilitar ltimo sangrado")
("disable last indentation after" "deshabilitar ltimo sangrado despus")
("disable last indentation before" "deshabilitar ltimo sangrado antes")
("disallow" "no permitir")
("distribute unused space" "distribuir el espacio no utilizado")
;?
("div" "div")
("document" "documento")
("document format" "formato del documento")
("document style" "estilo del documento")
("document styles" "estilos de documento")
("documentation" "documentacin")
("documents are trees" "los documentos son rboles")
;nuevo
("do not remap" "no reasignar")
("dot" "punto")
("dots" "puntos")
("double stroke" "trazo doble")
("down" "abajo")
("dpi" "ppp")
("duplicate" "duplicada")
("dutch" "holands")
("dynamic libraries" "bibliotecas dinmicas")
("edit" "editar")
("editing tools" "herramientas de edicin")
("emacs prefix command" "comando con prefijo de emacs")
("email" "correo-e")
("emphasize" "con nfasis")
("emphasize text" "enfatizar texto")
("empty box" "caja vaca")
("enable first indentation" "habilitar primer sangrado")
("enable first indentation after" "habilitar primer sangrado despus")
("enable first indentation before" "habilitar primer sangrado antes")
("enable indentation" "habilitar sangrado")
("enable indentation after" "habilitar sangrado despus")
("enable indentation before" "habilitar sangrado antes")
("enable last indentation" "habilitar ltimo sangrado")
("enable last indentation after" "habilitar ltimo sangrado despus")
("enable last indentation before" "habilitar ltimo sangrado antes")
("encl" "adj.")
("end" "fin")
("english" "ingls")
("enter a title" "introduce un ttulo")
("enumerate" "lista numerada")
("enumerate|Alpha" "numerar|Alfa")
("enumerate|Roman" "numerar|Romano")
("enumerate|alpha" "numerar|alfa")
("enumerate|roman" "numerar|romano")
("env" "env")
("environment" "entorno")
("epilogue" "eplogo")
("equal" "igual")
("equation" "ecuacin")
("equations" "ecuaciones")
("equivalent for" "equivalente a")
("error" "error")
("esperanto" "esperanto")
("etruscan" "etrusco")
("evaluate" "evaluar")
("evaluate scheme expression" "evaluar expresin en scheme")
("even page footer" "pie de pgina par")
("even page header" "cabecera de pgina par")
("even page margin" "margen de pgina par")
("even page text" "texto de pgina par")
;?
("exact horizontal" "horizontal exacta")
("exact mode" "modo exacto")
("exam" "examen")
("example" "ejemplo")
("exclusive" "exclusivo")
("exclusive or" "o exclusivo")
("executable" "ejecutable")
("execute" "ejecutar")
("execute a TeXmacs command" "ejecuta un comando de TeXmacs")
("execute system command" "ejecutar comando del sistema")
("executive" "ejecutivo")
("exercise" "ejercicio")
("expand" "desarrollar")
;?
("explained" "explicada")
("export" "exportar")
("export as" "exportar como")
("extend or normal" "extendido o normal")
("extern " "externo")
("extra" "extra")
("extract format" "extraer formato")
("family" "familia")
("february" "febrero")
("figure" "figura")
("file" "fichero")
("file name" "nombre del fichero")
("file not found" "fichero no encontrado")
("find next match" "buscar el siguiente")
("find text" "buscar texto")
("finnish" "finlands")
("first contact" "primer contacto")
("first indentation" "primer sangrado")
("first item" "primer elemento")
("first page" "primera pgina")
("first start" "comienzo rpido")
("flat" "plana")
("flexibility" "elasticidad")
("flexibility factor for vertical spacing" "factor de flexibilidad para el espaciado vertical")
("float" "flotante")
("floating figure" "figura flotante")
("floating object" "objeto flotante")
("floating table" "tabla flotante")
("fold" "plegar")
("folded" "plegado")
("font" "tipo de letra")
("font base size" "tamao base del tipo")
("font dpi" "resolucin del tipo (ppp)")
("font family" "familia del tipo")
("font name" "nombre del tipo")
("font series" "estilo del tipo")
("font shape" "forma del tipo")
("font size" "tamao del tipo")
("font variant" "variante del tipo")
("fonts" "tipos de letra")
("footer" "pie")
("footnote" "nota al pie")
("for" "para")
("foreground" "primer plano")
("foreign" "extranjera")
("format" "formato")
("formatted date" "fecha formateada")
("formula" "frmula")
("formula style" "estilo de frmula")
("forward replace" "sustituir el siguiente")
("forward search" "buscar el siguiente")
("fraction" "fraccin")
("french" "francs")
("full manuals" "manuales completos")
("function" "funcin")
("further customization" "personalizacin adicional")
("future changes" "cambios futuros")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs viene sin ninguna forma de garanta legal")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs se desarrolla bajo la licencia pblica general GNU (GNU GPL)")
("general architecture of TeXmacs" "arquitectura general de TeXmacs")
("general negation" "negacin general")
("generating font file" "generando fichero del tipo")
("generic" "genrico")
("georgian" "georgiano")
("german" "alemn")
("getting started" "primeros pasos")
("glossary" "glosario")
("glossary entry" "entrada de glosario")
("glue" "pegar")
;?
("glue decorations" "pegar decorados")
("go" "ir")
("gothic" "gtica")
("graphical interface" "interfaz grfica")
;?
("grave" "grave")
("greater" "mayor que")
("greater or equal" "mayor o igual que")
("greek" "griego")
("greek letter" "letra griega")
("green" "verde")
("grey" "gris")
("group" "grupo")
("happy typing" "feliz escritura")
("has been aborted" "ha sido interrumpida")
("has completed its task" "ha acabado su tarea")
("hat" "sombrero")
("header" "cabecera")
("header and footer" "cabecera y pie")
("hebrew" "hebreo")
("height" "altura")
("height is exactly the specified height" "la altura es exactamente la especificada")
("height is maximum of specified height and box height" "la altura es la mayor de entre la especificada y la altura de caja")
("height is minimum of specified height and box height" "la altura es la menor de entre la especificada y la altura de caja")
("height magnification" "ampliacin de altura")
("help" "ayuda")
("help me" "aydame")
("help us" "aydanos")
("here" "aqu")
("home" "inicio")
("horizontal" "horizontal")
("horizontal cell alignment" "alineacin horizontal de celdas")
("horizontal ink separation" "separacin de entintado horizontal")
("horizontal part" "parte horizontal")
("horizontal position" "posicin horizontal")
("horizontal space" "espacio horizontal")
("horizontal table alignment" "alineacin horizontal de tabla")
("horizontally align cell to the base" "alinear la celda horizontalmente con la base")
("horizontally center the cell" "centrar horizontalmente la celda")
("how much longer may pages become" "cunto ms largas pueden hacerse las pginas")
("how much shorter may pages become" "cunto ms cortas pueden hacerse las pginas")
("huge" "enorme")
("hungarian" "hngaro")
("hyperlink" "hiperenlace")
("hyphenation" "guionado")
("icelandic" "islands")
("if" "si")
("image" "imagen")
("image links" "vnculos a imgenes")
("implementation" "implementacin")
("import" "importar")
("improving the current implementation" "mejorar la implementacin actual")
("inactive" "inactivo")
("include" "incluir fichero")
("include a document" "incluir un documento")
("include file" "incluir fichero")
("inclusion into TeXmacs" "inclusin en TeXmacs")
("inclusions" "inclusiones")
;?
("indent" "sangrar")
("indentation flag" "marcador de sangrado")
("index" "ndice de materias")
("index entry" "entrada de ndice")
("index level" "nivel de ndice")
("insert" "insertar")
("insert Pr" "insertar Pr")
("insert a TeXmacs symbol" "insertar un smbolo de TeXmacs")
("insert a big operator" "insertar un operador grande")
("insert a binary operation" "insertar una operacin binaria")
("insert a binary relation" "insertar una relacin binaria")
("insert a blackboard bold character" "insertar un carcter de negrita de pizarra")
("insert a bold calligraphic character" "insertar un carcter en negrita caligrfica")
("insert a bold character" "insertar un carcter en negrita")
("insert a calligraphic character" "insertar un carcter en caligrfica")
("insert a fraction" "insertar una fraccin")
("insert a fraktur character" "insertar un carcter en frctur")
("insert a greek character" "insertar un carcter griego")
("insert a large left delimiter" "insertar un delimitador grande a la izquierda")
("insert a large right delimiter" "insertar un delimitador grande a la derecha")
("insert a large separator" "insertar un gran separador")
("insert a left subscript" "insertar un subndice a la izquierda")
("insert a link" "insertar un enlace")
("insert a miscellaneous symbol" "insertar un smbolo miscelneo")
("insert a new branch" "insertar una nueva rama")
("insert a new item" "insertar un nuevo elemento")
("insert a picture" "insertar una imagen")
("insert a square root" "insertar una raz cuadrada")
("insert a table" "insertar tabla")
("insert a table or a matrix" "insertar una tabla o una matriz")
("insert an" "insertar un/a")
("insert an accent" "insertar un acento")
("insert an arrow" "insertar una flecha")
("insert an environment" "insertar un nuevo entorno")
("insert an n" "insertar una n")
("insert appendix" "insertar apndice")
("insert arccos" "insertar arccos")
("insert arcsin" "insertar arcsin")
("insert arctan" "insertar arctan")
("insert arg" "insertar arg")
("insert argument" "insertar argumento")
("insert automatically generated content" "insertar contenido generado automticamente")
("insert big contour integral" "insertar integral de contorno grande")
("insert big coproduct" "insertar coproductorio grande")
("insert big direct sum" "insertar suma directa grande")
("insert big dotted point" "insertar producto puntual grande")
("insert big integral" "insertar integral grande")
("insert big intersection" "insertar interseccin grande")
("insert big logical and" "insertar Y lgico grande")
("insert big logical or" "insertar O lgico grande")
("insert big product" "insertar productorio grande")
("insert big square union" "insertar unin cuadrada grande")
("insert big summation" "insertar sumatorio grande")
("insert big tensor product" "insertar producto tensorial grande")
("insert big union" "insertar unin grande")
("insert big union sum" "insertar suma unin grande")
("insert big vertical space" "insertar espacio vertical grande")
("insert chapter" "insertar captulo")
("insert column" "insertar columna")
("insert column to the left" "insertar columna a la izquierda")
("insert column to the right" "insertar columna a la derecha")
("insert cos" "insertar cos")
("insert cosh" "insertar cosh")
("insert cot" "insertar cot")
("insert coth" "insertar coth")
("insert csc" "insertar csc")
("insert deg" "insertar deg")
("insert det" "insertar det")
("insert dim" "insertar dim")
("insert dollar" "insertar dlar")
("insert equation" "insertar ecuacin")
("insert executable markup" "insertar cdigo ejecutable")
("insert exp" "insertar exp")
("insert footnote" "insertar nota")
("insert formula" "insertar frmula")
("insert gcd" "insertar gcd")
("insert hom" "insertar hom")
("insert horizontal interword space" "insertar espacio horizontal entre palabras")
("insert image" "insertar imagen")
("insert inactive markup" "insertar marcado inactivo")
("insert inf" "insertar inf")
("insert ker" "insertar ker")
("insert lg" "insertar lg")
("insert lim" "insertar lim")
("insert liminf" "insertar liminf")
("insert limsup" "insertar limsup")
("insert ln" "insertar ln")
("insert log" "insertar log")
("insert mathematics" "insertar matemticas")
("insert max" "insertar max")
("insert medium horizontal space" "insertar espacio horizontal medio")
("insert medium vertical space" "insertar espacio vertical medio")
("insert min" "insertar min")
("insert negative horizontal space" "insertar espacio horizontal negativo")
("insert new item or number" "insertar nuevo elemento o nmero")
("insert new rows or columns" "insertar nuevas filas o columnas")
("insert or delete rows or columns" "insertar o borrar filas o columnas")
("insert row" "insertar fila")
("insert row above" "insertar fila encima")
("insert row below" "insertar fila debajo")
("insert sec" "insertar sec")
("insert section" "insertar seccin")
;?
("insert sharp" "insertar almohadilla")
("insert sin" "insertar sin")
("insert sinh" "insertar sinh")
("insert small horizontal space" "insertar espacio horizontal pequeo")
("insert small vertical space" "insertar espacio vertical pequeo")
("insert structural markup" "insertar marcado estructural")
("insert subsection" "insertar subseccin")
("insert subsubsection" "insertar subsubseccin")
("insert sup" "insertar sup")
("insert tan" "insertar tan")
("insert tanh" "insertar tanh")
("insert thick horizontal space" "insertar espacio horizontal grueso")
("interface" "interfaz")
("interfacing" "comunicacin")
("interfacing TeXmacs with other systems" "comunicar TeXmacs con otros sistemas")
("interjection" "interjeccin")
("interline separation" "separacin entre lneas")
("interline space" "interlineado")
("internationalization" "internacionalizacin")
("interparagraph space" "espacio entre prrafos")
("interrupt execution" "interrumpir ejecucin")
("introduction" "introduccin")
("invisible" "invisible")
("invisible citation" "cita invisible")
("irish" "irlands")
("is running" "est ejecutndose")
("is tuple" "es una tupla")
("ispell does not respond" "ispell no responde")
("ispell is already busy" "ispell ya est ocupado")
("italian" "italiano")
("italic" "cursiva")
("italic right" "cursiva recta")
("item" "elemento")
("itemize" "bolos")
("january" "enero")
("japanese" "japons")
("july" "julio")
("june" "junio")
("justified" "justificado")
("justify text" "justificar el texto")
("key" "tecla")
("keyboard" "teclado")
("keyboard equivalent" "equivalencia de teclado")
("keyboard modifiers" "modificadores de teclado")
("keyboard shortcut" "atajo de teclado")
("keymaps" "disposicin del teclado")
("keyword" "palabra clave")
("keywords" "palabras clave")
("kill" "matar")
("known bugs" "gazapos conocidos")
("label" "etiqueta")
("landscape" "apaisado")
("language" "idioma")
("large" "grande")
("large closing bracket" "gran parntesis de cierre")
("large delimiter" "delimitador grande")
("large opening bracket" "gran parntesis de apertura")
("large separator" "separador grande")
("last indentation" "ltima sangra")
("last page" "ltima pgina")
("latex command" "comando de latex")
("latin" "latn")
("layout" "presentacin")
("lecture note" "notas de clase")
("left" "izquierda")
("left border" "borde izquierdo")
("left margin" "margen izquierdo")
("left padding" "acolchado izquierdo")
("left prime" "prima izquierda")
("left ragged" "alineado a la izquierda")
("left slanted" "inclinada izquierda")
("left subscript" "subndice a la izquierda")
("left superscript" "superndice a la izquierda")
("left surrounding" "entorno a la izquierda")
("legal" "legal")
("lemma" "lema")
("length" "longitud")
("less" "menos")
("less or equal" "menos o igual")
("letter" "carta")
("license" "licencia")
("light" "ligero")
("light grey" "gris claro")
("limitations" "limitaciones")
("limits" "lmites")
("line" "lnea")
("line break" "salto de lnea")
("line stretch" "elasticidad de la lnea")
("link" "enlace")
("link image" "vincular imagen")
("list" "lista")
("list of figures" "lista de figuras")
("list of tables" "lista de tablas")
("load" "cargar")
("load LaTeX file" "cargar fichero LaTeX")
("load TeX file" "cargar fichero TeX")
("load TeXmacs file" "cargar fichero TeXmacs")
("load TeXmacs style file" "cargar fichero de estilos de TeXmacs")
("load a file" "cargar un fichero")
("load buffer" "cargar bfer")
("load file" "cargar fichero")
("load html file" "cargar fichero html")
("load image" "cargar imagen")
("load in new window" "cargar en nueva ventana")
("load latex file" "cargar fichero latex")
("load more recent autosave file" "cargar el fichero autoguardado ms reciente")
("load tex file" "cargar fichero tex")
("load verbatim file" "cargar fichero de texto plano")
("loaded" "cargado")
("long" "larga")
("look and feel" "aspecto y comportamiento")
("look up" "buscar")
("lower border" "borde inferior")
("macro" "macro")
("magenta" "magenta")
("magic" "mgico")
("magnification" "ampliacin")
("magnified" "ampliado")
("main" "principal")
("main icon bar" "barra de iconos principal")
("major changes" "cambios principales")
("make a page insertion" "hacer una insercin de pgina")
("make a subscript" "poner un subndice")
("make a superscript" "poner un superndice")
("make acute" "hacer agudo")
("make bar" "hacer barra")
;?
("make check" "hacer check")
("make fraction" "hacer fraccin")
("make grave" "hacer grave")
("make hat" "hacer sombrero")
("make label" "hacer etiqueta")
("make negation" "hacer negacin")
;?
("make page reference" "hacer referencia a pgina")
("make reference" "hacer referencia")
("make square root" "hacer raz cuadrada")
("make tilde" "hacer tilde")
("make title" "componer ttulo")
("make vector" "hacer vector")
("making donations" "donar")
("manual" "manual")
("map to" "se convierte en")
("march" "marzo")
("margins" "mrgenes")
("margins as on paper" "mrgenes como en el papel")
("master" "maestro")
("master file" "fichero maestro")
;?
("math" "matemtica")
("math font" "tipo matemtico")
("math font family" "familia de tipo matemtico")
("math font series" "estilo de tipo matemtico")
("math font shape" "forma de tipo matemtico")
("mathematical" "matemtico")
("mathematical formulas" "frmulas matemticas")
("mathematical typesetting" "composicin tipogrfica de las matemticas")
("mathematics" "matemticas")
("matrix" "matriz")
("maximal number of columns" "nmero mximo de columnas")
("maximal number of rows" "nmero mximo de filas")
("maximum mode" "modo mximo")
("may" "mayo")
("medium" "medio")
("medium skip" "salto mediano")
;?
("meminfo" "meminfo")
("merge" "fusionar")
;?
("messy" "liosa")
("meta key" "tecla meta")
("middle" "medio")
("minimal number of columns" "numero mnimo de columnas")
("minimal number of rows" "nmero mnimo de filas")
("minimum mode" "modo mnimo")
("minus" "menos")
("miscellaneous" "miscelnea")
("mod" "mod")
("mode" "modo")
("modifier" "modificador")
("modify cell alignment" "modificar alineacin de la celda")
("modify cell border" "modificar borde de celda")
("modify cell padding" "modificar acolchado de celda")
("modify cell size" "modificar tamao de celda")
("modify table border" "modificar borde de celda")
("modify table padding" "modificar acolchado de tabla")
("mongolian" "mongol")
("more information about GNU TeXmacs can be found in the help" "ms informacin sobre GNU TeXmacs en la ayuda")
("mosaic" "mosaico")
("move" "mover")
("move down" "ir abajo")
("move object" "mover objeto")
("move to the right when finished" "mueve a la derecha cuando termines")
("move up" "ir arriba")
("n-th" "ensima")
("n-th root" "raiz ensima")
("name" "nombre")
("negation" "negacin")
("new" "nuevo")
("new buffer" "nuevo bfer")
("new column" "nueva columna")
("new item" "nuevo elemento")
("new line" "nueva lnea")
("new number" "nuevo nmero")
("new page" "nueva pgina")
("new page before" "nueva pgina antes")
("new paragraph" "nuevo prrafo")
;?
("new roman" "nueva roman")
("new row" "nueva fila")
("new table" "nueva tabla")
("next line" "siguiente lnea")
("no changes need to be saved" "no hay cambios que guardar")
("no dictionary for" "no hay diccionario para")
;?
("no first indentation" "sin primer sangrado")
("no indentation" "sin sangrado")
("no last indentation" "sin ltimo sangrado")
("no line break" "no saltar de lnea")
("no matches found" "no se encontraron coincidencias")
("no more matches for" "no se encontraron ms coincidencias")
("no more redo information available" "no hay disponible ms informacin 'rehacer'")
("no more undo information available" "no hay disponible ms informacin 'deshacer'")
("no name" "sin nombre")
("no page break after" "sin salto de pgina posterior")
("no page break before" "sin salto de pgina anterior")
("no spelling errors found in text" "no se encontraron errores de ortografa")
("no style" "sin estilo")
("none" "nada")
("normal" "normal")
("norwegian" "noruego")
("not" "no")
;?
("not equal" "no igual")
("not found" "no encontrado")
("notation" "notacin")
("note" "nota")
("november" "noviembre")
("number" "nmero")
("number equation" "numerar ecuacin")
("number of columns" "nmero de columnas")
("numbered equation" "ecuacin numerada")
("numbered equations" "ecuaciones numeradas")
("numerator" "numerador")
("numeric" "numrico")
("objectives" "objetivos")
("occurrences" "apariciones")
("october" "octubre")
("odd page footer" "pie de pgina impar")
("odd page header" "cabecera de pgina impar")
("odd page margin" "margen de pgina impar")
("odd page text" "texto de pgina impar")
("off" "desactivado")
("ok" "vale")
("old english" "ingls antiguo")
("old slavonic" "eslavo antiguo")
("old style" "estilo antiguo")
("on" "activado")
("on cells" "sobre celdas")
("on columns" "sobre columnas")
("on entire table" "sobre la tabla entera")
("on rows" "sobre filas")
("one spelling error has been corrected" "un error ortogrfico corregido")
("online documentation" "documentacin en lnea")
("online help" "ayuda en lnea")
("open" "abrir")
("open a new buffer" "abrir un nuevo bfer")
("open new window" "abrir nueva ventana")
("opening" "apertura")
;?
("operation on named selection" "operacin sobre la seleccin indicada")
("operation on primary selection" "operacin sobre la seleccin primaria")
("operation on secondary selection" "operacin sobre la seleccin secundaria")
("operation on ternary selection" "operacin sobre la seleccin ternaria")
("optical" "ptico")
("option" "opcin")
("options" "opciones")
("or" "o")
("orange" "naranja")
("orientation" "orientacin")
("origin" "origen")
("original welcome message" "mensaje original de bienvenida")
("other" "otro")
("other pages" "otras pginas")
("other projects" "otros proyectos")
("other style" "otro estilo")
("outlined roman" "perfil romano")
("over" "sobre")
("padding" "acolchado")
("page" "pgina")
("page bottom margin" "margen inferior de pgina")
("page break" "salto de pgina")
("page break before" "salto de pgina antes")
("page height" "alto de pgina")
("page insertion" "insercin de pgina")
("page layout" "presentacin de pgina")
("page number text" "texto para nmero de pgina")
("page numbering" "numeracin de pginas")
("page reference" "referencia de pgina")
("page right margin" "margen derecho de pgina")
;nuevo
("page setup" "configuracin de pgina")
("page top margin" "margen superior de pgina")
("page type" "tipo de pgina")
("page width" "ancho de pgina")
("paper" "papel")
("paper type" "tipo de papel")
("papyrus" "papiro")
("paragraph" "prrafo")
("paragraph mode" "modo del prrafo")
("paragraph width" "ancho del prrafo")
("part" "parte")
("past changes" "cambios pasados")
("paste" "pegar")
("paste from" "pegar desde")
("paste text" "pegar texto")
("path" "camino")
("perform operations on cells" "operar sobre celdas")
("perform operations on columns" "operar sobre columnas")
("perform operations on entire table" "operar sobre la tabla entera")
("perform operations on rows" "operar sobre filas")
("permanent" "permanente")
("person" "persona")
("personal dictionary has been modified" "el diccionario personal ha sido modificado")
("phantasy" "fantasa")
("philosophy" "filosofa")
("phoenician" "fenicio")
("phonetic" "fontico")
("pink" "rosa")
("plain block" "bloque normal")
("plain tabular" "tabla normal")
("planned changes" "cambios planeados")
("plans for the future" "planes para el futuro")
("please" "por favor")
("please wait" "por favor, espera")
("plus" "ms")
("polish" "polaco")
("porting TeXmacs to other platforms" "portar TeXmacs a otras plataformas")
("portrait" "vertical")
("portuguese" "portugus")
("position" "posicin")
;?
("position float" "ubicar flotante")
("position floating object" "ubicar objeto flotante")
("position the table" "ubicar la tabla")
("postscript" "postscript")
("postscript image" "imagen postscript")
("pre-alpha release" "versin prealfa")
("preamble" "prembulo")
("preamble mode" "modo prembulo")
("preferences" "preferencias")
("presentation mode" "modo presentacin")
("preview before printing" "previsualizar antes de imprimir")
;?
("preview with ghostview" "previsualizar con ghostview")
("preview command" "comando de previsualizacin")
("primary" "primario")
("prime" "prima")
("print" "imprimir")
("print all" "imprimir todo")
("print all to file" "imprimir todo en un fichero")
("print page selection" "imprimir la seleccin")
("print page selection to file" "imprimir la seleccin en un fichero")
("print to postscript file" "imprimir en fichero postscript")
("printer" "impresora")
("printer dpi" "ppp de la impresora")
("printing command" "comando de impresin")
("problem" "problema")
("professional" "profesional")
("prog" "prog")
("prog font" "tipo prog")
("prog font family" "familia de tipo prog")
("prog font series" "estilo del tipo prog")
("prog font shape" "forma del tipo prog")
("program" "programa")
("program mode" "modo programa")
;?
("programming" "programacin")
("progressive" "progresivo")
("project" "proyecto")
("projects" "proyectos")
("prologue" "prlogo")
("prompt on scripts" "preguntar sobre los guiones")
("proof" "demostracin")
("proportional" "proporcional")
("proportional typewriter" "de ancho fijo proporcional")
("proposition" "proposicin")
("query replace" "buscar y reemplazar")
("quit" "salir")
("quotation" "cita (varios prrafos)")
("quote" "cita")
("range" "rango")
("really close it" "cerrarlo de verdad")
("really huge" "gigante")
("really quit" "salir de verdad")
("red" "rojo")
("redo" "rehacer")
("redo undone changes" "rehacer los cambios deshechos")
("reduce bottom margin by" "reducir margen inferior en")
("reduce left margin by" "reducir margen izquierdo en")
("reduce margins" "reducir mrgenes")
("reduce right margin by" "reducir margen derecho en")
("reduce top margin by" "reducir margen superior en")
("reduction even page margin" "reduccin del margen de pgina par")
("reduction odd page margin" "reduccin del margen de pgina impar")
("reduction page bottom margin" "reduccin del margen inferior de pgina")
("reduction page right margin" "reduccin del margen derecho de pgina")
("reduction page top margin" "reduccin del margen superior de pgina")
("reference" "referencia")
("references" "referencias")
("regular" "normal")
("release" "versin")
("reload" "recargar")
("remark" "observacin")
("remove number" "eliminar nmero")
("remove this switch" "eliminar este fotograma")
("renumber this page" "renumerar esta pgina")
("repeat object" "repetir objeto")
("replace" "sustituir")
("replace by" "sustituir por")
("replaced" "sustituido")
("replaced one occurrence" "sustituda una aparicin")
("reset" "reiniciar")
("resize object" "cambiar tamao del objeto")
("resized" "tamao cambiado")
("return" "return")
("revert" "volver al original")
("revert buffer" "recuperar el bfer")
("right" "derecha")
("right border" "borde derecho")
("right margin" "margen derecho")
("right padding" "acolchado derecho")
("right ragged" "alineado a la derecha")
("right subscript" "subndice a la derecha")
("right superscript" "superndice a la derecha")
("right surrounding" "entorno derecho")
("rigid" "rgido")
("rigid horizontal" "horizontal rgida")
("rigid space" "espacio rgido")
("romanian" "rumano")
("root" "raz")
("rotate backward" "rotar hacia atrs")
("rotate forward" "rotar hacia delante")
("row" "fila")
("row contains glued items" "la fila contiene elementos pegados")
("runic" "rnico")
("running author" "autor en cabecera o pie")
("running title" "ttulo en cabecera o pie")
("russian" "ruso")
("russian and Ukrainian users" "usuarios rusos y ucranianos")
("sample" "muestra")
("sans serif" "sin serifado")
("save" "guardar")
("save TeXmacs file" "guardar fichero TeXmacs")
("save TeXmacs style file" "guardar fichero de estilos TeXmacs")
("save as" "guardar como")
("save as LaTeX" "guardar como LaTeX")
("save as TeX" "guardar como TeX")
("save buffer" "guardar bfer")
("save buffer as" "guardar bfer como")
("save file" "guardar fichero")
("save html file" "guardar fichero html")
("save image" "guardar imagen")
("save latex file" "guardar fichero latex")
("save tex file" "guardar fichero tex")
("save this buffer" "guardar este bfer")
("save verbatim file" "guardar fichero de texto plano")
("saved" "guardado")
("screen layout" "presentacin en pantalla")
("screen margins" "mrgenes en pantalla")
("script" "ndice")
("script above" "ndice arriba")
("script below" "ndice debajo")
("script script size" "tamao de ndice de ndice")
("script size" "tamao de ndice")
("scripts not accepted" "no se aceptan guiones")
("search" "buscar")
("searching" "buscando")
("secondary" "secundario")
("section" "seccin")
("security" "seguridad")
("see" "ver")
("select a document style" "seleccionar un estilo de documento")
("select a foreground color" "seleccionar un color de primer plano")
("select a language" "seleccionar un idioma")
("selected region" "regin seleccionada")
("selection" "seleccin")
("selections" "selecciones")
("seminar" "seminario")
("separation between lines" "separacin entre lneas")
("separation between paragraphs" "separacin entre prrafos")
("separator" "separador")
("september" "septiembre")
("serb" "serbio")
("series" "estilo")
("series|right" "estilo|recta")
("session" "sesin")
("session name" "nombre de la sesin")
("session type" "tipo de sesin")
("sessions" "sessiones")
("set" "fijar")
("set background color of cell" "fijar color de fondo de celda")
("set cell mode" "fijar modo de celda")
("set extension center" "fijar centro de extensin")
("set height" "fijar altura")
("set height of cell" "fijar altura de celda")
("set margins" "fijar mrgenes")
("set n" "fijar n")
("set paragraph margins" "fijar mrgenes de prrafo")
("set paragraph mode" "fijar modo de prrafo")
("set printer dpi" "establecer resolucin de la impresora (ppp)")
("set printing command" "indicar comando de impresin")
;?
("set span" "fijar alcance")
("set special cell properties" "fijar propiedades especiales de celda")
("set special table properties" "fijar propiedades especiales de tabla")
("set text width" "fijar ancho del texto")
("set width" "fijar anchura")
("set width of cell" "fijar anchura de celda")
("settings" "ajustes")
("setup printer" "configurar la impresora")
("shape" "forma")
("shift-down" "shift-abajo")
("shift-right" "shift-derecha")
("show" "mostrar")
("show header and footer" "mostrar cabecera y pie")
("show on screen" "mostrar en pantalla")
("shrinking factor" "factor de reduccin")
("signature" "firma")
("single" "sencillo")
("size" "tamao")
("size limits" "lmites de tamao")
("slanted" "inclinada")
("sloppy" "laxo")
("small" "pequeo")
("small caps" "versalitas")
("small figure" "figura pequea")
("small skip" "salto pequeo")
("small table" "tabla pequea")
("source code" "cdigo fuente")
("space" "espacio")
("space between lines" "espacio entre lneas")
("space between paragraphs" "espacio entre prrafos")
("spacing" "espaciado")
("spanish" "espaol")
("special" "especial")
("special cell properties" "propiedades especiales de celda")
("special table properties" "propiedades especiales de tabla")
("specific" "especfico")
("spell" "ortografa")
("spell checking complete" "comprobacin de ortografa finalizada")
("spelling error" "error ortogrfico")
("spelling errors have been corrected" "se han corregido las faltas de ortografa")
("split" "partir")
("square root" "raz cuadrada")
("standard" "estndar")
("start" "empieza")
("start a new chapter" "empezar un nuevo captulo")
("start a new section" "empezar una nueva seccin")
("start an interactive session" "empezar una sesin interactiva")
("status bar" "barra de estado")
("stretchable" "estirable")
("stretchable horizontal" "estirable horizontal")
("stretchable vertical" "estirable vertical")
("stroke" "trazo")
("strokes" "trazos")
("strong" "resaltado")
("structural" "estructural")
("style" "estilo")
("styles" "estilos")
("sub" "sub")
("subparagraph" "subprrafo")
("subscript" "subndice")
("subsection" "subseccin")
("subsub" "subsub")
("subsubsection" "subsubseccin")
("summary" "resumen")
("summary of the principal TeXmacs tags" "resumen de los principales elementos de marcado de TeXmacs")
("superpose" "superponer")
("superposed" "superpuesto")
("superscript" "superndice")
("swedish" "sueco")
("switch" "fotogramas")
("switch to first" "cambiar al primero")
("switch to formula style" "cambiar a estilo de frmula")
("switch to last" "cambiar al ltimo")
("switch to next" "cambiar al siguiente")
("switch to previous" "cambiar al anterior")
("switching and folding" "fotogramas y entornos plegados")
("symbol" "smbolo")
("system environment variables" "variables de entorno del sistema")
("tab" "tabulador")
("table" "tabla")
("table command" "comando de tabla")
("table of contents" "ndice")
("tables" "tablas")
;?
("tabular" "tabular")
("tabular material" "material tabular")
("teXmacs as an interface" "teXmacs como interfaz")
("teXmacs fonts" "tipos de letra de TeXmacs")
("teXmacs notice" "aviso de TeXmacs")
("teXmacs style files" "ficheros de estilo de TeXmacs")
("ternary" "ternario")
("test" "probar")
("tex" "tex")
("text" "texto")
("text font" "tipo texto")
("text height correction" "correcin de altura de texto")
("text width" "ancho de texto")
("texts" "textos")
("th century bc" "-ava centuria ac")
("th root" "sima raiz")
("thai" "tailands")
("the TeXmacs authors" "los autores de TeXmacs")
("the application did not send its usual startup banner" "la aplicacin no envi su aviso de inicio habitual")
("the application does not reply" "la aplicacin no responde")
("the application is already running" "la aplicacin ya se est ejecutando")
("the boxes produced by the typesetter" "las cajas producidas por el sistema de composicin")
("the graphical user interface" "el interfaz grfico de usuario")
("the leaves of TeXmacs trees" "las hojas de los rboles de TeXmacs")
("the mycas example" "el ejemplo de mycas")
("the primitive TeXmacs constructs" "las construcciones primitivas de TeXmacs")
("the standard TeXmacs styles" "los estilos estndar de TeXmacs")
("theorem" "teorema")
("there are unsaved files" "hay ficheros sin guardar")
("this buffer has not been saved" "no se ha grabado este bfer")
("this document has been produced using" "este documento ha sido producido utilizando")
("this line" "esta lnea")
("this page" "esta pgina")
("tilda" "tilda")
("tilde" "tilde")
("times" "times")
("tiny" "diminuto")
("title" "ttulo")
("to the left" "a la izquierda")
("to the right" "a la derecha")
("today" "hoy")
("tools" "herramientas")
;?
("top" "arriba del todo")
("top border" "borde superior")
("top level" "nivel superior")
("top margin" "margen superior")
("top padding" "acolchado superior")
("translate" "traducir")
("tree" "rbol")
("tuple" "tupla")
("turkish" "turco")
("tutorial" "tutorial")
("type" "tipo")
("type a latex command followed by" "escribe un comando de latex seguido por")
("type body" "escribe el cuerpo")
("type denominator" "escribe el denominador")
("type numerator" "escribe el numerador")
("type script" "escribe el ndice")
("typesetted boxes" "composicin tipogrfica de cajas")
("typewriter" "ancho fijo")
("typewriter small caps" "versalitas de ancho fijo")
("typing a simple text" "teclear un texto sencillo")
("typing simple texts" "teclear textos sencillos")
("ugaritic" "ugartico")
("ukrainian" "ucraniano")
("undo" "deshacer")
("undo last changes" "deshacer los ltimos cambios")
("up" "arriba")
("update" "actualizar")
("update from web" "actualizar desde la red")
("update image links" "actualizar vnculos a imgenes")
("upper border" "borde superior")
("use TeXmacs" "usar TeXmacs")
("use a black color" "usar color negro")
("use a blue color" "usar color azul")
("use a bold font" "usar un tipo en negrita")
("use a brown color" "usar color marrn")
("use a calligraphic font" "usar un tipo caligrfico")
("use a green color" "usar color verde")
("use a grey color" "usar color gris")
("use a magenta color" "usar color magenta")
("use a orange color" "usar color naranja")
("use a pink color" "usar color rosa")
("use a red color" "usar color rojo")
("use a sans serif font" "usar un tipo sin serifado")
("use a typewriter font" "usar un tipo de ancho fijo")
("use a white color" "usar color blanco")
("use a yellow color" "usar color amarillo")
("use blackboard bold font" "usar tipo negrita de pizarra")
("use bold font series" "usar serie negrita")
("use calligraphical font" "usar tipo caligrfico")
("use footnote font size" "usar tamao de tipo nota al pie")
("use fraktur font" "usar tipo fraktur")
("use huge font size" "usar tamao de tipo enorme")
("use italic font shape" "usar forma de tipo cursiva")
("use large font size" "usar tamao de tipo grande")
("use left hand column as border" "usar columna de la izquierda como borde")
("use medium font series" "usar serie de tipo medio")
("use normal font size" "usar tamao de tipo normal")
("use package" "usar paquete")
("use paragraph width" "usar anchura de prrafo")
("use really huge font size" "usar tamao de tipo gigante")
("use right font shape" "usar forma de tipo recta")
("use right hand column as border" "usar columna de la derecha como borde")
("use roman font family" "usar familia de tipos romana")
("use row above as border" "usar fila superior como borde")
("use row below as border" "usar fila inferior como borde")
("use sans serif font family" "usar familia de tipos sans serif")
("use script font size" "usar tamao de tipo ndice")
("use slanted font shape" "usar forma de tipo inclinada")
("use small capitals" "usar versalitas")
("use small font size" "usar tamao de tipo pequeo")
("use small-caps font shape" "usar forma de tipo versalitas")
("use the blackboard bold font" "usar el tipo negrita de pizarra")
("use the fraktur font" "usar el tipo fraktur")
("use tiny font font size" "usar tamao de tipo diminuto")
("use typewriter font family" "usar familia de tipos de ancho fijo")
("use very large font size" "usar tamao de tipo muy grande")
("user manual" "manual de usuario")
("user provided icons" "iconos proporcionados por el usuario")
("value" "valor")
("variable" "variable")
("variant" "variante")
("vector" "vector")
("verbatim" "sin formato")
("verse" "verso")
("vertical" "vertical")
("vertical after" "vertical posterior")
("vertical before" "vertical anterior")
("vertical cell alignment" "alineacin vertical de celda")
("vertical part" "parte vertical")
("vertical position" "posicin vertical")
("vertical space" "espacio vertical")
("vertical table alignment" "alineacin vertical de tabla")
("vertically align cell to the base" "linear verticalmente la celda a la base")
("vertically center the cell" "centrar verticalmente la celda")
("very large" "muy grande")
("very small" "muy pequeo")
("vietnamese" "vietnamita")
("view" "ver")
("visible" "visible")
("warning" "aviso")
("welcome" "bienvenido")
("welcome to GNU TeXmacs" "bienvenido a GNU TeXmacs")
("what is new" "qu es nuevo")
("when finished" "cuando termines")
("while" "mientras")
("white" "blanco")
("wide accent" "acento ancho")
("width" "ancho")
("width is exactly the specified width" "la anchura es exactamente la especificada")
("width is maximum of specified width and box width" "la anchura es la mayor de entre la especificada y de la de la caja")
("width is minimum of specified width and box width" "la anchura es la menor de entre la especificada y la de la caja")
("width magnification" "ampliacin de anchura")
("window" "ventana")
("window height" "altura de la ventana")
("window width" "anchura de la ventana")
("windows key" "tecla de Windows")
("with" "con")
("write a name" "escribir un nombre")
("write bold mathematics" "escribir matemticas en negrita")
("write bold text" "escribir en negrita")
("write italic text" "escribir en cursiva")
("write sample text" "escribir un texto de ejemplo")
("write strong text" "escribir texto resaltado")
("write typewriter text" "escribir texto de ancho fijo")
("write verbatim text" "escribir texto sin formato")
("writing data converters" "escribir traductores de datos")
("writing your own style files" "escribir tus propios ficheros de estilo")
("yellow" "amarillo")
("you can also obtain" "tambin puedes obtener")
("your document is back in its original state" "el documento ha vuelto a su estado original")
("your first interface" "tu primer interfaz")
; new entries for 1.0.1.21
("background evaluations" "evaluaciones en segundo plano")
("basic communication using pipes" "comunicacin bsica por tuberas")
("completion" "complecin")
("content" "contenido")
("custum tab" "tab personalizado")
("fold input field" "campo de entrada plegado")
("formatted and structured output" "salida formateada y estructurada")
("input mode" "modo de entrada")
("insert a wide symbol above" "insertar smbolo ancho sobre")
("insert a wide symbol below" "insertar smbolo ancho bajo")
("insert fields" "insertar campos")
("insert input field above" "insertar campo de entrada sobre")
("insert input field below" "insertar campo de entrada bajo")
("insert text field" "insertar campo de texto")
("left arrow" "flecha izquierda")
("mathematical and customized input" "entrada matemtica y personalizada")
("mathematical input" "entrada matemtica")
("miscellaneous features" "caractersticas miscelneas")
("multiline input" "entrada multilnea")
("my documents" "mis documentos")
("no matches found for" "no se encontraron coincidencias para")
("overbrace" "llave por encima")
("overline" "lnea por encima")
("plugin" "plugin")
("plugins" "plugins")
("presentation" "presentacin")
("prompts and default input" "Prompts y entrada por defecto")
("remove all output fields" "quitar todos los campos de salida")
("remove fields" "quitar campos")
("remove input field" "quitar campo de entrada")
("remove input field above" "quitar campo de entrada arriba")
("search results for" "resultados de la bsqueda de")
("right arrow" "flecha derecha")
("search words in my documents" "buscar palabras en mis documentos")
("search words in the documentation" "buscar palabras en la documentacin")
("search words in the source code" "buscar palabras en el cdigo fuente")
("sending commands to TeXmacs" "cmo enviar comandos a TeXmacs")
("split session" "dividir sesiones")
("teXmacs plugins" "plugins de TeXmacs")
("underbrace" "llave por debajo")
("underline" "lnea por debajo")
("users of Cyrillic languages" "usuarios de cirlico")
("wide bar" "barra ancha")
("your language" "su idioma")
("browse forward" "siguiente")
("browse back" "anterior")
("pageup" "RePag")
("find file" "buscar fichero")
("A.M.S. subject classification" "clasificacin por temas de la AMS")
("caps-lock key" "tecla bloqueo de maysculas")
("extras" "extra")
("insert large" "insertar un gran")
("reduction bottom margin" "reduccin del margen inferior")
("reduction right margin" "reduccin del margen derecho")
("reduction top margin" "reduccin del margen superior")
("right page margin" "margen de la pgina a la derecha)
("roman" "roman")
("use calligraphic font" "utilizar tipo caligrfico")
("more information about GNU TeXmacs can be found in the Help" "Puedes encontrar ms informacin sobre GNU TeXmacs en la ayuda")
